@@ -20,7 +20,6 @@ import os
 
 # external packages
 import PyQt5.QtWidgets
-from PyQt5.QtCore import QMutex
 import numpy as np
 from scipy.interpolate import griddata
 from scipy.ndimage import uniform_filter
@@ -37,6 +36,7 @@ import sep
 
 # local import
 from mountcontrol.convert import convertToDMS, convertToHMS
+from mountcontrol.convert import formatHstrToText, formatDstrToText
 from base.fitsHeader import getCoordinates, getSQM, getExposure, getScale
 from gui.utilities import toolsQtWidget
 from gui.widgets import image_ui
@@ -120,7 +120,7 @@ class ImageWindow(toolsQtWidget.MWidget):
                           }
 
         self.imageMat = self.embedMatplot(self.ui.image, constrainedLayout=False)
-        self.imageMat.parentWidget().setStyleSheet(self.BACK_BG)
+        # self.imageMat.parentWidget().setStyleSheet(self.BACK_BG)
         self.fig = self.imageMat.figure
         self.axe = None
         self.axeCB = None
@@ -168,8 +168,8 @@ class ImageWindow(toolsQtWidget.MWidget):
         if 'imageW' not in self.app.config:
             self.app.config['imageW'] = {}
         config = self.app.config['imageW']
-        config['winPosX'] = self.pos().x()
-        config['winPosY'] = self.pos().y()
+        config['winPosX'] = max(self.pos().x(), 0)
+        config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
         config['width'] = self.width()
         config['color'] = self.ui.color.currentIndex()
@@ -208,6 +208,7 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.ui.abortSolve.clicked.connect(self.abortSolve)
         self.signals.solveImage.connect(self.solveImage)
         self.app.showImage.connect(self.showImage)
+        self.app.colorChange.connect(self.colorChange)
         self.show()
         self.showCurrent()
         return True
@@ -239,9 +240,17 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.ui.abortSolve.clicked.disconnect(self.abortSolve)
         self.signals.solveImage.disconnect(self.solveImage)
         self.app.showImage.disconnect(self.showImage)
-        plt.close(self.imageMat.figure)
+        self.app.colorChange.disconnect(self.colorChange)
         super().closeEvent(closeEvent)
 
+    def colorChange(self):
+        """
+        :return:
+        """
+        self.setStyleSheet(self.mw4Style)
+        self.showCurrent()
+        return True
+
     def setupDropDownGui(self):
         """
         :return: success for test
@@ -341,7 +350,7 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.fig.clf()
         self.axe = self.fig.add_subplot(1, 1, 1,
                                         projection=wcs.WCS(self.header, relax=True),
-                                        facecolor=self.M_GREY_LIGHT)
+                                        facecolor=self.M_BACK)
 
         self.fig.subplots_adjust(bottom=0.1, top=0.9, left=0.1, right=0.85)
         self.axeCB = None
@@ -380,7 +389,7 @@ class ImageWindow(toolsQtWidget.MWidget):
         """
         self.fig.clf()
         self.axe = self.fig.add_subplot(1, 1, 1,
-                                        facecolor=self.M_GREY_LIGHT)
+                                        facecolor=self.M_BACK)
 
         self.fig.subplots_adjust(bottom=0.1, top=0.9, left=0.1, right=0.85)
         self.axeCB = self.fig.add_axes([0.88, 0.1, 0.02, 0.8])
@@ -401,7 +410,7 @@ class ImageWindow(toolsQtWidget.MWidget):
             self.axe.axhline(midY, color=self.M_RED)
 
         if self.ui.checkShowGrid.isChecked():
-            self.axe.grid(True, color=self.M_BLUE, ls='solid', alpha=0.5)
+            self.axe.grid(True, color=self.M_GREY, ls='solid', alpha=1)
 
         self.axe.tick_params(axis='x', which='major',
                              colors=self.M_BLUE, labelsize=12)
@@ -589,8 +598,8 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         ra, dec = getCoordinates(header=self.header)
 
-        self.ui.ra.setText(f'{self.formatHstrToText(ra)}')
-        self.ui.dec.setText(f'{self.formatDstrToText(dec)}')
+        self.ui.ra.setText(f'{formatHstrToText(ra)}')
+        self.ui.dec.setText(f'{formatDstrToText(dec)}')
 
         scale = getScale(header=self.header)
         rotation = self.header.get('ANGLE', 0)
@@ -781,8 +790,8 @@ class ImageWindow(toolsQtWidget.MWidget):
         with fits.open(imagePath, mode='update') as fitsHandle:
             self.image = fitsHandle[0].data
             self.header = fitsHandle[0].header
-            
-        if self.image is None or self.image == []:
+
+        if self.image is None or len(self.image) == 0:
             return False
         if self.header is None:
             return False
