@@ -66,7 +66,7 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.camController.setLinearSpeed(5.0)
         self.camController.setLookSpeed(90)
         self.view.setRootEntity(self.rootEntity)
-        self.view.defaultFrameGraph().setClearColor(QColor(24, 24, 24))
+        self.view.defaultFrameGraph().setClearColor(QColor(self.M_BACK))
 
         self.pL0E = QEntity(self.rootEntity)
         self.pL0 = QPointLight(self.pL0E)
@@ -128,8 +128,8 @@ class SimulatorWindow(toolsQtWidget.MWidget):
             self.app.config['simulatorW'] = {}
 
         config = self.app.config['simulatorW']
-        config['winPosX'] = self.pos().x()
-        config['winPosY'] = self.pos().y()
+        config['winPosX'] = max(self.pos().x(), 0)
+        config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
         config['width'] = self.width()
         pos = self.camera.position()
@@ -176,6 +176,7 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.app.drawBuildPoints.disconnect(self.buildPointsCreate)
         self.app.drawHorizonPoints.disconnect(self.horizonCreate)
         self.camera.positionChanged.disconnect(self.limitPositionZ)
+        self.app.colorChange.disconnect(self.colorChange)
         super().closeEvent(closeEvent)
 
     def showWindow(self):
@@ -207,9 +208,19 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.app.drawBuildPoints.connect(self.buildPointsCreate)
         self.app.drawHorizonPoints.connect(self.horizonCreate)
         self.camera.positionChanged.connect(self.limitPositionZ)
+        self.app.colorChange.connect(self.colorChange)
         self.show()
         return True
 
+    def colorChange(self):
+        """
+        :return:
+        """
+        self.setStyleSheet(self.mw4Style)
+        self.view.defaultFrameGraph().setClearColor(QColor(self.M_BACK))
+        self.createScene(self.rootEntity)
+        return True
+
     def limitPositionZ(self):
         """
         :return:
@@ -384,8 +395,8 @@ class SimulatorWindow(toolsQtWidget.MWidget):
 
     def createScene(self, rEntity):
         """
-        createScene initially builds all 3d models and collects them to a scene. please look
-        closely which references are used-
+        createScene initially builds all 3d models and collects them to a scene.
+        please look closely which references are used-
 
         :param rEntity:
         :return:
@@ -430,8 +441,9 @@ class SimulatorWindow(toolsQtWidget.MWidget):
 
     def updateSettings(self):
         """
-        updateSettings resize parts depending on the setting made in the dome tab. likewise
-        some transformations have to be reverted as they are propagated through entity linking.
+        updateSettings resize parts depending on the setting made in the dome tab.
+        likewise some transformations have to be reverted as they are propagated
+        through entity linking.
 
         :return:
         """
