@@ -18,11 +18,9 @@ from base import packageConfig
 
 # standard libraries
 from datetime import datetime
-import gc
 import time
 
 # external packages
-from PyQt5.QtGui import QPixmap
 from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QWidget
 from PyQt5.QtTest import QTest
@@ -32,6 +30,7 @@ if packageConfig.isAvailable:
     from gui.extWindows.simulatorW import SimulatorWindow
     from gui.extWindows.keypadW import KeypadWindow
 
+from gui.utilities.stylesQtCss import Styles
 from gui.utilities.toolsQtWidget import MWidget
 from gui.extWindows.messageW import MessageWindow
 from gui.extWindows.hemisphereW import HemisphereWindow
@@ -46,7 +45,8 @@ from gui.mainWmixin.tabAlmanac import Almanac
 from gui.mainWmixin.tabModel import Model
 from gui.mainWmixin.tabBuildPoints import BuildPoints
 from gui.mainWmixin.tabManageModel import ManageModel
-from gui.mainWmixin.tabSatellite import Satellite
+from gui.mainWmixin.tabSatSearch import SatSearch
+from gui.mainWmixin.tabSatTrack import SatTrack
 from gui.mainWmixin.tabMinorPlanetTime import MinorPlanetTime
 from gui.mainWmixin.tabRelay import Relay
 from gui.mainWmixin.tabTools import Tools
@@ -70,7 +70,8 @@ class MainWindow(
     Model,
     BuildPoints,
     ManageModel,
-    Satellite,
+    SatSearch,
+    SatTrack,
     MinorPlanetTime,
     Relay,
     Power,
@@ -90,19 +91,19 @@ class MainWindow(
     for managing async processing if needed.
     """
 
-    __all__ = [
-        "MainWindow",
-    ]
+    __all__ = ['MainWindow']
 
     def __init__(self, app):
+        # has to be put before super to adjust the color before the stylesheet
+        # on the parent classes is drawn first
+        colSet = app.config.get('colorSet', 0)
+        Styles.colorSet = colSet
         super().__init__()
-
         self.app = app
         self.threadPool = app.threadPool
         self.deviceStat = app.deviceStat
         self.uiWindows = app.uiWindows
         self.setAttribute(Qt.WA_DeleteOnClose)
-
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
         self.closing = False
@@ -151,13 +152,12 @@ class MainWindow(
                 'name': 'SimulatorDialog',
                 'class': SimulatorWindow,
             }
-        if packageConfig.isAvailable:
-            self.uiWindows['showKeypadW'] = {
-                'button': self.ui.openKeypadW,
-                'classObj': None,
-                'name': 'KeypadDialog',
-                'class': KeypadWindow,
-            }
+        self.uiWindows['showKeypadW'] = {
+            'button': self.ui.openKeypadW,
+            'classObj': None,
+            'name': 'KeypadDialog',
+            'class': KeypadWindow,
+        }
         self.deviceStatGui = {
             'dome': self.ui.domeConnected,
             'camera': self.ui.cameraConnected,
@@ -191,6 +191,7 @@ class MainWindow(
             self.uiWindows[window]['button'].clicked.connect(self.toggleWindow)
 
         self.initConfig()
+        self.ui.colorSet.currentIndexChanged.connect(self.refreshColorSet)
         self.showExtendedWindows()
 
         self.app.update1s.connect(self.updateTime)
@@ -226,6 +227,10 @@ class MainWindow(
         """
         config = self.app.config
         self.ui.profile.setText(config.get('profileName'))
+        colSet = config.get('colorSet', 0)
+        Styles.colorSet = colSet
+        self.ui.colorSet.setCurrentIndex(colSet)
+        self.setStyleSheet(self.mw4Style)
         if 'mainW' not in config:
             config['mainW'] = {}
         config = config['mainW']
@@ -244,6 +249,7 @@ class MainWindow(
         self.ui.mainTabWidget.setCurrentIndex(config.get('mainTabWidget', 0))
         self.ui.settingsTabWidget.setCurrentIndex(config.get('settingsTabWidget', 0))
         self.ui.toolsTabWidget.setCurrentIndex(config.get('toolsTabWidget', 0))
+        self.ui.satTabWidget.setCurrentIndex(config.get('satTabWidget', 0))
         if not packageConfig.isAnalyse:
             tabWidget = self.ui.toolsTabWidget.findChild(QWidget, 'Analyse')
             tabIndex = self.ui.toolsTabWidget.indexOf(tabWidget)
@@ -256,7 +262,8 @@ class MainWindow(
         tabWidget = self.ui.toolsTabWidget.findChild(QWidget, 'Relay')
         tabIndex = self.ui.toolsTabWidget.indexOf(tabWidget)
         self.ui.toolsTabWidget.setTabEnabled(tabIndex, False)
-        self.ui.toolsTabWidget.setStyleSheet(self.getStyle())
+        ui = self.ui.toolsTabWidget
+        ui.setStyleSheet(ui.styleSheet())
         self.mwSuper('initConfig')
         self.changeStyleDynamic(self.ui.mountConnected, 'color', 'gray')
         self.setupIcons()
@@ -277,48 +284,39 @@ class MainWindow(
 
     def storeConfig(self):
         """
-        storeConfig writes the keys to the configuration dict and stores. if some
-        saving has to be proceeded to persistent data, they will be launched as
-        well in this method.
-
         :return: True for test purpose
         """
         config = self.app.config
+        config['colorSet'] = self.ui.colorSet.currentIndex()
         config['profileName'] = self.ui.profile.text()
         if 'mainW' not in config:
             config['mainW'] = {}
-
         config = config['mainW']
         config['winPosX'] = self.pos().x()
         config['winPosY'] = self.pos().y()
         config['mainTabWidget'] = self.ui.mainTabWidget.currentIndex()
         config['settingsTabWidget'] = self.ui.settingsTabWidget.currentIndex()
         config['toolsTabWidget'] = self.ui.toolsTabWidget.currentIndex()
+        config['satTabWidget'] = self.ui.satTabWidget.currentIndex()
         self.mwSuper('storeConfig')
         self.storeConfigExtendedWindows()
         return True
 
     def closeEvent(self, closeEvent):
         """
-        we overwrite the close event of the window just for the main window to
-        close the application as well. because it does not make sense to have
-        child windows open if main is already closed.
-
         :return:    nothing
         """
         self.closing = True
-        self.stopDrivers()
         self.app.timer0_1s.stop()
         self.changeStyleDynamic(self.ui.pauseModel, 'pause', False)
         self.closeExtendedWindows()
+        self.stopDrivers()
+        self.threadPool.waitForDone(5000)
         super().closeEvent(closeEvent)
         self.app.quit()
 
     def quitSave(self):
         """
-        quitSave finished up and calls the quit save function in main for
-        saving the parameters
-
         :return:    true for test purpose
         """
         self.saveProfile()
@@ -328,9 +326,6 @@ class MainWindow(
 
     def setupIcons(self):
         """
-        setupIcons add icon from standard library to certain buttons for improving the
-        gui of the app.
-
         :return:    True if success for test
         """
         # main window
@@ -378,9 +373,9 @@ class MainWindow(
 
         # model
         self.wIcon(self.ui.plateSolveSync, 'start')
-        pixmap = QPixmap(':/pics/azimuth.png')
+        pixmap = self.img2pixmap(':/pics/azimuth.png')
         self.ui.picAZ.setPixmap(pixmap)
-        pixmap = QPixmap(':/pics/altitude.png')
+        pixmap = self.img2pixmap(':/pics/altitude.png')
         self.ui.picALT.setPixmap(pixmap)
 
         self.wIcon(self.ui.cancelModel, 'cross-circle')
@@ -405,6 +400,7 @@ class MainWindow(
         self.wIcon(self.ui.refreshModel, 'reload')
 
         # minor planets
+        self.wIcon(self.ui.mpcExtendedFilter, 'cogs')
         self.wIcon(self.ui.progMinorPlanetsFull, 'run')
         self.wIcon(self.ui.progMinorPlanetsFiltered, 'run')
         self.wIcon(self.ui.progEarthRotationData, 'run')
@@ -474,25 +470,25 @@ class MainWindow(
         self.wIcon(self.ui.coverUnpark, 'exit-up')
 
         # dome setting
-        pixmap = QPixmap(':/dome/radius.png')
+        pixmap = self.img2pixmap(':/dome/radius.png')
         self.ui.picDome1.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/north.png')
+        pixmap = self.img2pixmap(':/dome/north.png')
         self.ui.picDome2.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/east.png')
+        pixmap = self.img2pixmap(':/dome/east.png')
         self.ui.picDome3.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/z_gem.png')
+        pixmap = self.img2pixmap(':/dome/z_gem.png')
         self.ui.picDome4.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/z_10micron.png')
+        pixmap = self.img2pixmap(':/dome/z_10micron.png')
         self.ui.picDome5.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/gem.png')
+        pixmap = self.img2pixmap(':/dome/gem.png')
         self.ui.picDome6.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/lat.png')
+        pixmap = self.img2pixmap(':/dome/lat.png')
         self.ui.picDome7.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/shutter.png')
+        pixmap = self.img2pixmap(':/dome/shutter.png')
         self.ui.picDome8.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/hysteresis.png')
+        pixmap = self.img2pixmap(':/dome/hysteresis.png')
         self.ui.picDome9.setPixmap(pixmap)
-        pixmap = QPixmap(':/dome/zenith.png')
+        pixmap = self.img2pixmap(':/dome/zenith.png')
         self.ui.picDome10.setPixmap(pixmap)
         self.wIcon(self.ui.copyFromDomeDriver, 'copy')
         self.wIcon(self.ui.domeCloseShutter, 'exit-down')
@@ -611,6 +607,12 @@ class MainWindow(
         else:
             self.ui.refractionGroup.setEnabled(False)
             self.ui.setRefractionManual.setEnabled(False)
+
+        if self.deviceStat.get('dome') and self.deviceStat.get('mount'):
+            self.ui.useDomeAz.setEnabled(True)
+        else:
+            self.ui.useDomeAz.setEnabled(False)
+
         return True
 
     def smartTabGui(self):
@@ -643,8 +645,10 @@ class MainWindow(
         # redraw tabs only when a change occurred. this is necessary, because
         # enable and disable does not remove tabs
         if tabChanged:
-            self.ui.mainTabWidget.setStyleSheet(self.getStyle())
-            self.ui.settingsTabWidget.setStyleSheet(self.getStyle())
+            ui = self.ui.mainTabWidget
+            ui.setStyleSheet(ui.styleSheet())
+            ui = self.ui.settingsTabWidget
+            ui.setStyleSheet(ui.styleSheet())
         return True
 
     def smartEnvironGui(self):
@@ -802,7 +806,23 @@ class MainWindow(
                 continue
             self.uiWindows[window]['classObj'] = None
 
-        gc.collect()
+        return True
+
+    def setColorSet(self):
+        """
+        :return:
+        """
+        Styles.colorSet = self.ui.colorSet.currentIndex()
+        return True
+
+    def refreshColorSet(self):
+        """
+        :return:
+        """
+        self.setColorSet()
+        self.setStyleSheet(self.mw4Style)
+        self.setupIcons()
+        self.app.colorChange.emit()
         return True
 
     def buildWindow(self, window):
