@@ -25,7 +25,19 @@ import platform
 import socket
 import sys
 import traceback
+from base.loggerMW import setupLogging
+setupLogging()
+#
+# the following lines should avoid errors messages from OLE Automation with PyQt5
+# see
+# https://stackoverflow.com/questions/51284268/
+#         windowscontext-oleinitialize-failed-com-error-0x80010106-rpc-e-changed-mode
+# and https://github.com/pywinauto/pywinauto/issues/472
+# order is important to set sys.coinit_flags = 2 before import pywinauto
+#
 import warnings
+warnings.simplefilter('ignore', UserWarning)
+sys.coinit_flags = 2
 
 # external packages
 import astropy
@@ -37,7 +49,6 @@ from PyQt5.QtWidgets import QWidget, QApplication, QTabBar, QComboBox, QPushButt
 from importlib_metadata import version
 
 # local import
-from base.loggerMW import setupLogging
 from gui.utilities.splashScreen import SplashScreen
 from mainApp import MountWizzard4
 import resource.resources as res
@@ -49,9 +60,6 @@ astropy.utils.iers.conf.auto_download = False
 astropy.utils.data.conf.allow_internet = False
 log = logging.getLogger()
 
-# the following lines should avoid errors messages from OLE Automation with PyQt5
-warnings.simplefilter("ignore", UserWarning)
-
 
 class QAwesomeTooltipEventFilter(QObject):
     """
@@ -182,7 +190,10 @@ class MyApp(QApplication):
         elif isinstance(obj, QLineEdit):
             self.log.ui(f'Click EditLine: [{obj.objectName()}]:{obj.text()}')
         else:
-            self.log.ui(f'Click Object  : [{obj.objectName()}]')
+            if obj.objectName() not in ['qt_scrollarea_viewport',
+                                        'QComboBoxPrivateContainerClassWindow',
+                                        '']:
+                self.log.ui(f'Click Object  : [{obj.objectName()}]')
 
         return returnValue
 
@@ -302,7 +313,7 @@ def extractDataFiles(mwGlob=None, splashW=None):
 
     files = {
         'de421_23.bsp': 0,
-        'active.txt': 0,
+        'visual.txt': 0,
         'CDFLeapSeconds.txt': 0,
         'finals2000A.all': 0,
         'finals.data': 0,
@@ -411,4 +422,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
