@@ -55,7 +55,7 @@ class Connection(object):
 
     # I don't want so wait to long for a response. In average I see values
     # shorter than 0.5 sec, so 2 seconds should be good
-    SOCKET_TIMEOUT = 3
+    SOCKET_TIMEOUT = 5
 
     # complete used command list to be checked first if valid
     # these are the commands, which were used in mountcontrol so far
@@ -67,13 +67,13 @@ class Connection(object):
                 ':GLDT', ':GMs', ':GMsa', ':GMsb', ':GMACW', ':GMAC',
                 ':GREF', ':GRPRS', ':GRTMP',
                 ':GS', ':GT', ':GTMP1', ':GUDT',
-                ':GVD', ':GVN', ':GVP', ':GVT', ':GVZ',
-                ':GWOL', ':Ga', ':GaXa', ':GaXb',
+                ':GVD', ':GVN', ':GVP', ':GVT', ':GVZ', ':GWOL',
+                ':Ga', ':GaE', ':GaXa', ':GaXb',
                 ':Gd', ':Gdat', ':Gev', ':Gg', ':Gh', ':GINQ', ':Ginfo', ':Glms',
                 ':Glmt', ':Gmte', ':Go', ':Gr', ':Gt', ':gtg', ':GTsid',
                 ':Guaf', ':Gz',
-                ':MA', ':MS', ':MaX', ':Me', ':Mn', ':Ms', ':Mw',
-                ':MSao', ':MSap',
+                ':MA', ':MS', ':MSao', ':MSap',
+                ':MaX', ':Me', ':Mn', ':Ms', ':Mw',
                 ':NTGdisc', ':NTGweb', ':NTSdisc', ':NTSweb',
                 ':NUtim',
                 ':PO', ':PO', ':PO', ':PaX', ':PiP',
@@ -85,7 +85,7 @@ class Connection(object):
                 ':Sdat', ':Sev', ':Sev', ':Sg', ':Sg', ':Sh', ':Slms', ':Slmt',
                 ':So', ':Sr', ':St', ':Suaf', ':Sw', ':Sz',
                 ':TLEG', ':TLEL0', ':TLEGAZ', ':TLEGEQ', ':TLEP', ':TLES',
-                ':TLESCK',
+                ':TLESCK', ':TROFFADD', ':TROFFCLR', ':TROFFGET', ':TROFFSET',
                 ':TRNEW', ':TRADD', ':TRP', ':TRREPLAY',
                 ':U2',
                 ':delalig', ':delalst',
@@ -210,7 +210,7 @@ class Connection(object):
             client.close()
 
         except Exception as e:
-            self.log.warning(f'hard close: {e}')
+            self.log.warning(f'Hard close, error: [{e}]')
             return False
 
         return True
@@ -225,7 +225,6 @@ class Connection(object):
         if not self.host:
             self.log.info(f'[{self.id}] no host defined')
             return None
-
         if not isinstance(self.host, tuple):
             self.log.info(f'[{self.id}] host entry malformed')
             return None
@@ -233,7 +232,6 @@ class Connection(object):
         client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         client.settimeout(self.SOCKET_TIMEOUT)
         client.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, True)
-
         try:
             client.connect(self.host)
 
@@ -244,12 +242,12 @@ class Connection(object):
 
         except socket.error as e:
             self.closeClientHard(client)
-            self.log.debug(f'[{self.id}] socket error: {e}')
+            self.log.debug(f'[{self.id}] socket error: [{e}]')
             return None
 
         except Exception as e:
             self.closeClientHard(client)
-            self.log.debug(f'[{self.id}] socket error: {e}')
+            self.log.debug(f'[{self.id}] socket error: [{e}]')
             return None
 
         else:
@@ -265,12 +263,10 @@ class Connection(object):
         """
         try:
             client.sendall(commandString.encode())
-
         except Exception as e:
             self.closeClientHard(client)
-            self.log.debug(f'[{self.id}] socket error: {e}')
+            self.log.debug(f'[{self.id}] socket error: [{e}]')
             return False
-
         else:
             return True
 
@@ -286,7 +282,6 @@ class Connection(object):
         :param minBytes: minimum number of data bytes
         :return: success and response data
         """
-
         response = ''
         receiving = True
         try:
@@ -294,9 +289,8 @@ class Connection(object):
                 chunkRaw = client.recv(2048)
                 try:
                     chunk = chunkRaw.decode('ASCII')
-
                 except Exception as e:
-                    self.log.warning(f'[{self.id}] {e}, {chunkRaw}')
+                    self.log.warning(f'[{self.id}] error: [{e}], received: [{chunkRaw}]')
                     return False, ''
 
                 if not chunk:
@@ -305,7 +299,6 @@ class Connection(object):
                 response += chunk
                 if numberOfChunks == 0 and len(response) == minBytes:
                     break
-
                 elif numberOfChunks != 0 and numberOfChunks == response.count('#'):
                     break
 
@@ -314,12 +307,12 @@ class Connection(object):
             return False, response
 
         except Exception as e:
-            self.log.debug(f'[{self.id}] socket error: {e}')
+            self.log.debug(f'[{self.id}] socket error: [{e}]')
             return False, response
 
         else:
             response = response.rstrip('#').split('#')
-            self.log.trace(f'[{self.id}] response : {response}')
+            self.log.trace(f'[{self.id}] response: [{response}]')
             return True, response
 
     def communicate(self, commandString):
@@ -334,20 +327,15 @@ class Connection(object):
                  numberOfChunks:    number of responses chunks which were
                                     split with #
         """
-
         if not self.validCommandSet(commandString):
             self.log.warning(f'[{self.id}] unknown commands: {commandString}')
             return False, 'wrong commands', 0
 
         numberOfChunks, getData, minBytes = self.analyseCommand(commandString)
-        logFormat = '[{0}] sending  : {1}, getData: {2}, minBytes: {3}, chunks: {4}, host: {5}'
-        self.log.trace(logFormat.format(self.id,
-                                        commandString,
-                                        getData,
-                                        minBytes,
-                                        numberOfChunks,
-                                        self.host,
-                                        ))
+
+        t = f'[{self.id}] sending: [{commandString}], getData: [{getData}],'
+        t += f'minBytes: [{minBytes}], numOfChunks: [{numberOfChunks}], host: [{self.host}]'
+        self.log.trace(t)
 
         client = self.buildClient()
         if client is None:
@@ -369,3 +357,31 @@ class Connection(object):
         del client
 
         return suc, response, numberOfChunks
+
+    def communicateRaw(self, commandString):
+        """
+        :param commandString:
+        :return:
+        """
+        client = self.buildClient()
+        if client is None:
+            return False, False, 'Socket error'
+        client.settimeout(1)
+        self.log.trace(f'[{self.id}] sending  : {commandString}')
+        sucSend = self.sendData(client=client, commandString=commandString)
+        try:
+            chunkRaw = client.recv(2048)
+            chunk = chunkRaw.decode('ASCII')
+        except socket.timeout:
+            self.log.debug(f'[{self.id}] socket timeout')
+            chunk = 'Timeout'
+            sucRec = False
+        except Exception as e:
+            self.log.debug(f'[{self.id}] socket error: [{e}]')
+            chunk = 'Exception'
+            sucRec = False
+        else:
+            self.log.trace(f'[{self.id}] response: [{chunk}]')
+            sucRec = True
+        finally:
+            return sucSend, sucRec, chunk
